@@ -1,7 +1,7 @@
 import logging
 import os
 
-import conda.config
+from conda_execute.conda_interface import envs_dirs, pkgs_dirs, rc
 
 
 log = logging.getLogger('conda-execute')
@@ -20,11 +20,11 @@ def setup_logging(level):
         logger.setLevel(level + offset)
 
 
-execute_config = conda.config.rc.get('conda-execute') or {}
-env_dir_template = execute_config.get('env-dir', '{config.envs_dirs[0]}/../tmp_envs')
+execute_config = rc.get('conda-execute') or {}
+env_dir_template = execute_config.get('env-dir', '%s/../tmp_envs' % envs_dirs[0])
 
 # Expand user and normalize the path.
-env_dir = os.path.normpath(os.path.expanduser(env_dir_template.format(config=conda.config)))
+env_dir = os.path.normpath(os.path.expanduser(env_dir_template))
 
 
 # The miniumum amount of time since a new process has used an environment
@@ -32,9 +32,9 @@ env_dir = os.path.normpath(os.path.expanduser(env_dir_template.format(config=con
 min_age = execute_config.get('remove-if-unused-for', 25)
 
 
-pkg_dir_template = execute_config.get('pkg-dir', '{config.pkgs_dirs[0]}')
+pkg_dir_template = execute_config.get('pkg-dir', pkgs_dirs[0])
 
 # Expand user and normalize the path.
-pkg_dir = os.path.normpath(os.path.expanduser(pkg_dir_template.format(config=conda.config)))
+pkg_dir = os.path.normpath(os.path.expanduser(pkg_dir_template))
 
 
